# mojave
## Tooig Operating System

Mojave is an architecture designed stritly to deliver on automation. 

We designed it to help manage certain backend functions that will bug the process of software and operations at Tooig in the future. it is also versatile enough that it can be used to develop other smaller variants.

Our first instance of a small variant is Genie. So far we've completed the build but we still need to run tests.



So far, we've given Mojave the ability to think, read and write from and to its long term memory. All we now need to do is to create the main tool needed for the actual rendering of 3D to the human interface.

## Distillation 

We have a plan to distill the function of Mojave to smaller models, and use them for several uses. In this case, we have to use it to build Genie's operating system. We'll go on to make the major tool in JavaScript. I still don't know how it's all going to come together.